package Net::DNS::RR::DHCID;

use strict;
use warnings;
our $VERSION = (qw$Id: DHCID.pm 1896 2023-01-30 12:59:25Z willem $)[2];

use base qw(Net::DNS::RR);



use integer;

use MIME::Base64;


sub _decode_rdata {			## decode rdata from wire-format octet string
	my ( $self, $data, $offset ) = @_;

	my $size = $self->{rdlength} - 3;
	@{$self}{qw(identifiertype digesttype digest)} = unpack "\@$offset nC a$size", $$data;
	return;
}


sub _encode_rdata {			## encode rdata as wire-format octet string
	my $self = shift;

	return pack 'nC a*', map { $self->$_ } qw(identifiertype digesttype digest);
}


sub _format_rdata {			## format rdata portion of RR string.
	my $self = shift;

	my @rdata = split /\s+/, encode_base64( $self->_encode_rdata );
	return @rdata;
}


sub _parse_rdata {			## populate RR from rdata in argument list
	my ( $self, @argument ) = @_;

	my $data = MIME::Base64::decode( join "", @argument );
	my $size = length($data) - 3;
	@{$self}{qw(identifiertype digesttype digest)} = unpack "n C a$size", $data;
	return;
}




sub identifiertype {
	my ( $self, @value ) = @_;
	for (@value) { $self->{identifiertype} = 0 + $_ }
	return $self->{identifiertype} || 0;
}


sub digesttype {
	my ( $self, @value ) = @_;
	for (@value) { $self->{digesttype} = 0 + $_ }
	return $self->{digesttype} || 0;
}


sub digest {
	my ( $self, @value ) = @_;
	for (@value) { $self->{digest} = $_ }
	return $self->{digest} || "";
}


1;
__END__


